@@ -1,4 +1,4 @@
-# Copyright (c) 2009 Simplistix Ltd
+# Copyright (c) 2009-2012 Simplistix Ltd
 #
 # See license.txt for more details.
 
@@ -7,7 +7,6 @@ import os
 from base import ContextTest,CommandContext,listall,cleanup
 from checker.checkers.path import check
 from testfixtures import compare
-from unittest import TestSuite,makeSuite
 
 class TestPath(ContextTest):
 
@@ -44,7 +43,21 @@ class TestPath(ContextTest):
                 "LC_COLLATE=\"C\" ls -laR --time-style=+ '/some/deep/path'",
                 ])
 
-def test_suite():
-    return TestSuite((
-        makeSuite(TestPath),
-        ))
+    def test_storage_path_already_exists(self):
+        # This is the key element of this test:
+        self.c.dir.makedir('something')
+        
+        self.c.r.replace('subprocess.mswindows',False)
+        # pretend only our path exists
+        path = '/something'
+        self.c.existing_paths.add(path)
+
+        compare(check(self.c.config_folder, path), '')
+        compare(listall(self.c.dir),[
+                'something.listing',
+                'something',
+                ])
+        compare(self.c.called,[
+                "cp -R '/something' '<config>'",
+                "LC_COLLATE=\"C\" ls -laR --time-style=+ '/something'",
+                ])
